#
# spec file for package libgnomekbd
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 8
Name:           libgnomekbd
Version:        3.28.1
Release:        1.9
Summary:        GNOME Keyboard Library
License:        LGPL-2.1-or-later
Group:          System/GUI/GNOME
URL:            https://gitlab.gnome.org/GNOME/libgnomekbd
Source0:        https://download.gnome.org/sources/libgnomekbd/3.28/%{name}-%{version}.tar.xz

# PATCH-FIX-UPSTREAM libgnomekbd-avoid-coredump-on-ibus-engines.patch bnc#1160963, glgo#GNOME/libgnomekbd!6 qzhao@suse.com -- To avoid crash when working with ibus.
Patch0:         libgnomekbd-avoid-coredump-on-ibus-engines.patch
# PATCH-FIX-OPENSUSE libgnomekbd-set-default-indicator.patch bnc#1034390 qzhao@suse.com -- set the common keyboard layout indicator as default to avoid misleading.
Patch1:         libgnomekbd-set-default-indicator.patch

BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.44
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libxklavier) >= 5.2

%description
GNOME keyboard library and utility.

%package -n gnomekbd-tools
Summary:        GNOME Keyboard tools
Group:          System/GUI/GNOME
Conflicts:      %{name} < 3.26.1

%description -n gnomekbd-tools
GNOME keyboard library and utility.

This package provides various binaries and conversion tools for
libgnomekbd.

%package -n libgnomekbd%{sover}
Summary:        GNOME Keyboard Library
# Make -lang package installable, and ease upgrade path
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n libgnomekbd%{sover}
GNOME keyboard shared library.

This package provides the shared library of libgnomekbd.

%package -n typelib-1_0-Gkbd-3_0
Summary:        Introspection bindings for libgnomekbd
Group:          System/Libraries
Conflicts:      %{name} < 3.26.1

%description -n typelib-1_0-Gkbd-3_0
GNOME keyboard library and utility.

This package provides the GObject Introspection bindings for
libgnomekbd.

%package devel
Summary:        GNOME Keyboard Library
Group:          Development/Libraries/GNOME
Requires:       %{name}%{sover} = %{version}
Requires:       gnomekbd-tools = %{version}
Requires:       typelib-1_0-Gkbd-3_0 = %{version}

%description devel
This package contains the header files for developing
applications that want to make use of libgnomekbd.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}/%{_prefix}

%ldconfig_scriptlets -n libgnomekbd%{sover}

%files -n gnomekbd-tools
%{_bindir}/gkbd-keyboard-display
%dir %{_datadir}/GConf
%dir %{_datadir}/GConf/gsettings
%{_datadir}/GConf/gsettings/libgnomekbd.convert
%{_datadir}/applications/gkbd-keyboard-display.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.libgnomekbd.desktop.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.libgnomekbd.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.libgnomekbd.keyboard.gschema.xml
%{_datadir}/libgnomekbd/

%files -n libgnomekbd%{sover}
%license COPYING.LIB
%{_libdir}/*so.*

%files -n typelib-1_0-Gkbd-3_0
%{_libdir}/girepository-1.0/Gkbd-3.0.typelib

%files lang -f %{name}.lang

%files devel
%{_includedir}/libgnomekbd/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/gir-1.0/Gkbd-3.0.gir

%changelog
* Mon Sep  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.28.1:
  + Land several fixes to meson build definitions to align with
    autotools.
- Switch to meson build system:
  + Add meson BuildRequires.
  + Replace %%configure/%%make%%make_install macros with meson
    equivalents %%meson/%%meson_build/%%meson_install
  + Drop libtool BuildRequires and no longer call autogen.sh
* Wed Aug 24 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Rebase patches with quilt.
- Use ldconfig_scriptlets macro for post(un) handling.
* Fri Aug 19 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.28.0:
  + Require GLib 2.44
  + Modernize the codebase
  + Avoid several crashes
  + Fix RTL issues
  + Add meson build system
  + Updated translations.
- Add libtool BuildRequires and call autgen.sh in build phase: the
  tarball was geneated using meson and does not contain configure.
  It is not possible (yet) to use meson as build system though, as
  the installation turns out to be incomplete.
- Drop libgnomekbd_avoid_implicit_definition.patch: Fixed upstream.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Tue Jun  1 2021 Cliff Zhao <qzhao@suse.com>
- Add libgnomekbd_avoid_implicit_definition.patch: Add string.h into
  include files to avoid inplicit definition warning in building.
  This change is to meet the needs of the inspection of maintaince
  build checking script(bnc#1160963, bnc#1034390,
  glgo#GNOME/libgnomekbd!7)
* Mon May 24 2021 Cliff Zhao <qzhao@suse.com>
- Add libgnomekbd-set-default-indicator.patch: set the common
  keyboard layout indicator as "default" to avoid misleading
  (bnc#1034390).
* Fri Apr  2 2021 Cliff Zhao <qzhao@suse.com>
- Add libgnomekbd-avoid-coredump-on-ibus-engines.patch: avoid libgnomekbd
  crash when working with ibus(bnc#1160963, glgo#GNOME/libgnomekbd!6).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue Nov  5 2019 Frederic Crozat <fcrozat@suse.com>
- Add explicit conflicts in typelib-1_0-Gkbd-3_0 and gnomekbd-tools
  against libgnomekbd < 3.26.1, before package split was done.
* Tue Apr 30 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Make -lang package installable and ease upgrade: provide/obsolete
  libgnomekbd by libgnomekbd8.
* Thu Apr 18 2019 Jan Engelhardt <jengelh@inai.de>
- Remove --with-pic which has no effect with --disable-static.
* Fri Mar  1 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Split package to SLPP standard:
  + Add sover define and set it to 8.
  + New subpackage gnomekbd-tools.
  + New subpackage libgnomekbd8.
  + New subpackage typelib-1_0-Gkbd-3_0.
  + Drop BUILD_FROM_VCS conditionals.
  + Add post(un) handling of the new shared library package.
  + Update URL to current GNOME gitlab home.
- Drop libgnomekbd-default-group-switch.patch: It does not seem to
  make any noticeable change today.
- Modernize spec, run spec-cleaner, drop post(un) handling of
  glib2_gsettings_schema_post(un) and desktop_database_post(un) and
  glib2_gsettings_schema_requires macro.
* Wed Feb  6 2019 bjorn.lie@gmail.com
- Update to version 3.26.1:
  + Fix build with new GLib.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Sep 12 2017 dimstar@opensuse.org
- Update to version 3.26.0:
  + Fix icon filename in Portuguese and Serbian translations.
  + Fix untranslated app name on the panel.
  + Updated translations.
* Tue Sep 20 2016 zaitor@opensuse.org
- Update to version 3.22.0.1:
  + Fix non-installed gschemas.
- Changes from version 3.22.0:
  + No changes.
* Wed Sep 14 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Draw keys with invalid keycodes.
  + Fix modifier key pressed state.
  + Build system and minor code cleanups.
  + Avoid crashes on wayland sessions.
  + Updated translations.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Sat Aug 25 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Updated translations.
* Sun Jun 10 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Removed xmodmap support, would be handled in g-s-d through the
    scripts.
  + Some minor build fixes.
- Rebase libgnomekbd-default-group-switch.patch.
* Wed Mar 28 2012 vuntz@opensuse.org
- Update to version 3.4.0.2:
  + Really fix issues introduced in 3.4.0.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0.1:
  + Revert "Small memory leak fixed": it was a bad idea.
- Change update-desktop-files BuildRequires to desktop-file-utils:
  we don't need %%suse_update_desktop_file anymore, but we need the
  %%desktop_database_* macros.
* Sun Mar 25 2012 dimstar@opensuse.org
- Update to version 3.4.0:
  + Dropping obsolete plugins architecture.
  + Small memory leak fixed.
  + Options comparison improved.
* Wed Feb 22 2012 vuntz@opensuse.org
- Update to version 3.3.90:
  + Some build fixes
  + Some deprecated APIs changed to the new ones
  + The introspection is now linked to libxklavier
* Wed Sep 28 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
* Thu Sep 22 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Fix build issues.
  + Updated translations.
* Thu Sep  1 2011 vuntz@opensuse.org
- Drop explicit Requires from devel packages that will
  automatically be added the pkg-config way: dbus-1-glib-devel,
  gconf2-devel, gtk3-devel, libxklavier-devel.
* Tue Aug 23 2011 dimstar@opensuse.org
- Update to version 3.1.90:
  + Couple of minor bugs fixed.
  + Updated translations.
* Wed Apr  6 2011 fcrozat@novell.com
- Update to version 3.0.0.1:
  + Fix color of status indicator in fallback mode.
  + Fix initial size of status indicator.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Updated translations
- Changes from version 2.91.92:
  + Minor fixes
* Tue Mar  8 2011 fcrozat@novell.com
- Update to version 2.91.91:
  + More improvements in the drawing widget.
  + Small build/runtime fixes
  + Updated translations.
* Wed Feb 23 2011 fcrozat@novell.com
- Update to version 2.91.90:
  + A lot of improvements in the drawing widget.
  + Updated for new libxklavier 5.1.
  + Separate gkbd-keyboard-display app.
  + Updated translations
- Changes from version 2.91.5:
  + Big refactoring: common code from both indicators is separated
    into GkbdConfiguration.
  + Introspection added, for embedding into JS-driven gnome-shell.
  + A number of bugs and build issues fixed.
  + Still trying to catch fast changing gtk APIs.
- Changes from version 2.91.4:
  + Fix build with latest GTK3
  + Updated translations
- enable introspection support
- Drop libgnomekbd-fix-gtk3.patch: fixed upstream.
- Change gtk2-devel Requires to gtk3-devel in devel subpackage.
- Add support for source service checkout, with %%BUILD_FROM_VCS:
  + Add gnome-common BuildRequires.
  + Add call to ./autogen.sh.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Fri Dec 17 2010 vuntz@opensuse.org
- Update to version 2.91.3.1:
  + Fix build with GTK3.
- Changes from version 2.91.3:
  + More changes related to GTK3.
  + Eliminated one crasher
  + Updated translations.
- Changes from version 2.91.2:
  + Further changes related to GTK3.
  + Simple xmodmap support introduced (moved from
    gnome-settings-daemon).
  + I18N fixed.
  + Updated translations.
- Changes from version 2.91.1:
  + Changed API - from gconf to gsettings.
  + Ported to GTK3
- Remove gconf2-devel, gtk2-devel BuildRequires.
- Move to pkgconfig()-style BuildRequires:
  + Old ones: libxklavier-devel
  + New ones: glib-2.0, libxklavier.
- Add pkgconfig(gtk+-3.0) BuildRequires.
- Rebase libgnomekbd-default-group-switch.patch.
- Add libgnomekbd-fix-gtk3.patch to fix build with GTK+ 2.91.6.
- Remove all the gconf schema handling (%%gconf_schemas_prereq,
  %%find_gconf_schemas and scriptlets).
- Handle gsettings schemas: add %%glib2_gsettings_schema_requires
  and %%glib2_gsettings_schema_post(un) in the scriptlets.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + Updated translations.
* Sat Sep 18 2010 vuntz@opensuse.org
- Update to version 2.31.92:
  + Some rendering switched to Cairo.
  + Updated translations.
* Tue Aug 31 2010 aj@suse.de
- Recommend instead of require lang package since it's not mandatory.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 2.31.5:
  + One crasher fixed
  + Rendering improved
  + Updated translations.
- Add libgnomekbd-default-group-switch.patch to change the group
  switch keybinding to shifts_toggle, since that's what we use in
  openSUSE.
* Wed Jul 14 2010 dimstar@opensuse.org
- Update to version 2.31.2:
  + Seriously improved status icon rendering
- Changes from version 2.31.1:
  + Several crashers fixed
  + Provided API for handling the default group switcher. Changed
    the default value to be "grp:shift_caps_toggle"
  + Updated translations.
- Drop upstream included patches libgnomekbd-fix-crash.patch and
  libgnomekbd-proper-notification-name.patch.
* Thu Jun 17 2010 vuntz@opensuse.org
- Add two patches from git:
  + libgnomekbd-fix-crash.patch: fix a crash in
    gnome-settings-daemon that can ruin your session in some
    circumstances (after unlocking screensaver, for example)
  + libgnomekbd-proper-notification-name.patch: make sure the
    notification icon is properly positioned in the notification
    area.
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 2.30.1:
  + Seriously improved status icon rendering
  + Updated translations.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + One crash fixed (excessing unref)
  + Better support for gnome/gtk themes
  + Updated translations.
* Tue Mar  9 2010 dimstar@opensuse.org
- Update to version 2.29.92:
  + GkbdStatus is using gtk/gnome font settings
  + A lot of translations fixed
  + Explicit dbus dependency dropped
- Drop dbus-1-glib-devel BuildRequire.
* Wed Jan 13 2010 captain.magnus@opensuse.org
- Update to version 2.29.5:
  + GkbdIndicator rendering fixed
  + GkbdStatus notification icon added
* Sun Dec 13 2009 dimstar@opensuse.org
- Update to version 2.28.2:
  + Small fixes for the rendering.
- Do not install en@shaw locale on openSUSE <= 11.2.
* Wed Sep 23 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Updated translations.
* Wed Sep  9 2009 vuntz@opensuse.org
- Remove libgnome-devel Requires from devel package.
* Thu Aug 27 2009 vuntz@novell.com
- Update to version 2.27.91:
  + Minor fixes.
  + Updated translations.
- Use spec-cleaner script to reorder lines in preamble.
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 2.27.4:
  + Update to libxklavier 4.0.
* Wed May 27 2009 vuntz@novell.com
- Update to version 2.27.2:
  + Replacing libglade with gtkbuilder
  + Updated translations.
- Remove libglade2-devel BuildRequires, and add gtk2-devel
  BuildRequires.
* Mon Mar 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Sat Mar 14 2009 vuntz@novell.com
- Update to version 2.26.0:
  + Two bugs related to deprecated APIs fixed.
* Sun Feb 22 2009 vuntz@novell.com
- Update to version 2.25.91:
  + Several small bugs/build issues ar closed
- Remove BuildRequires: gnome-common
* Wed Jan 28 2009 vuntz@novell.com
- Call %%suse_update_desktop_file on all desktop files. Part of
  bnc#445728.
* Mon Jan 26 2009 crrodriguez@suse.de
- remove "la" files [BNC#357465]
* Tue Sep 23 2008 maw@suse.de
- Update to version 2.24.0:
  + Minor fixes
- Drop libgnomekbd-allow-old-dbus.patch
- Misc., minor .spec file cleanups
- Don't package libtool archives or static libraries.
* Mon Jun 16 2008 maw@suse.de
- Update to version 2.23.2:
  + Drop old and unneeded code
  + Make the default size of the preview depend upon the screen's
    size.
* Wed Apr  2 2008 rodrigo@suse.de
- Update to version 2.22.0:
  * Use tango icons
- Removed non-existing icon from installation
* Fri Jan 25 2008 rodrigo@suse.de
- Updated to version 2.21.4.1:
  * Fix for the indicators crash in keyboard drawing
  * Keyboard drawing printing functions moved to libgnomekbd, from
    gnome-control-center
* Tue Sep 18 2007 sbrabec@suse.cz
- Updated to version 2.20.0:
  * minor fix to the build process
  * new translations
* Thu Aug 30 2007 maw@suse.de
- Update to version 2.19.91:
  + Bug fixes
  + Updated translations.
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage
- s#%%run_ldconfig#/sbin/ldconfig/ in %%post and %%postun.
* Thu Jul 19 2007 sbrabec@suse.cz
- Allow to build with old dbus.
* Fri Jul  6 2007 maw@suse.de
- Update to version 2.18.2
- Several keyboard drawing bugs fixed
- Incorrect GObject usage crash fixed
- Added translations.
* Fri May 11 2007 pgajdos@suse.cz
- removed
  - gnome-icon-theme-devel from BuildRequires
  - gnome-icon-theme       from Requires
- [#247450]
* Wed Apr 11 2007 maw@suse.de
- Update to version 2.18.1
- Updated translations
- Bug fixes.
* Mon Mar  5 2007 sbrabec@suse.cz
- Spec file cleanup.
* Tue Feb 27 2007 maw@suse.de
- New package.
